--[[

$Revision: 69 $

(C) Copyright 2009 Bethink (bethink at naef dot com)
See LICENSE.txt for license terms.

]]


----------------------------------------------------------------------
-- Initialization

local L = LibStub("AceLocale-3.0"):GetLocale("BossNotes")


----------------------------------------------------------------------
-- Encounters

BOSS_NOTES_ENCOUNTERS = {
	-- Wrath of the Lich King Raid
	{
		instanceSetId = "WotlkRaid",
		default = true,
		instances = {
			{
				instanceId = "Ulduar",
				encounters = {
					{
						-- Flame Leviathan
						encounterId = 33113
					},
					{
						-- Razorscale
						encounterId = 33186
					},
					{
						-- XT-002 Deconstructor
						encounterId = 33293
					},
					{
						-- Ignis the Furnace Master
						encounterId = 33118
					},
					{
						-- Iron Council
						encounterId = 32867
					},
					{
						-- Kologarn
						encounterId = 32930
					},
					{
						-- Auriaya
						encounterId = 33515
					},
					{
						-- Mimiron
						encounterId = 33350
					},
					{
						-- Hodir
						encounterId = 32845
					},
					{
						-- Thorim
						encounterId = 32865
					},
					{
						-- Freya
						encounterId = 32906
					},
					{
						-- General Vezax
						encounterId = 33271
					},
					--[[
					{
						-- Yogg-Saron
						encounterId = 33288 -- TODO: check
					},
					{
						-- Algalon the Observer
						encounterId = 0 -- TODO: check
					}
					]]
				}
			},
			{
				instanceId = "Naxxramas",
				npcIds = { 16018, 15975, 15978, 16156, 16146, 16145, 16163, 29818, 15974, 16024,
						16236, 16036, 16244, 16385, 16021, 16027, 16020, 30083, 16297, 15981,
						15980, 16165, 16017, 16034, 16037, 16375, 16164, 16193, 16029, 30071,
						16025, 16168, 16022, 15979, 16194, 16215, 16216, 15976 },
				encounters = {
					{
						-- Anub'rekhan
						encounterId = 15956,
						npcIds = { 15956, 16573 }
					},
					{
						-- Grand Widow Faerlina
						encounterId = 15953,
						npcIds = { 15953, 16505, 16506 }
					},
					{
						-- Maexxna
						encounterId = 15952,
					},
					{
						-- Noth the Plaguebringer
						encounterId = 15954,
						npcIds = { 15954, 16983, 16984 }
					},
					{
						-- Heigan the Unclean
						encounterId = 15936
					},
					{
						-- Loatheb
						encounterId = 16011,
						npcIds = { 16011, 16286 }
					},
					{
						-- Instructor Razuvious
						encounterId = 16061
					},
					{
						-- Gothik the Harvester
						encounterId = 16060,
						npcIds = { 16060, 16148, 16149, 16150, 16127, 16125, 16126, 16124 }
					},
					{
						-- The Four Horsemen
						encounterId = 16063,
						npcIds = { 30549, 16065, 16063, 16064 }
					},
					{
						-- Patchwerk
						encounterId = 16028
					},
					{
						-- Grobbulus
						encounterId = 15931,
						npcIds = { 15931, 16363 }
					},
					{
						-- Gluth
						encounterId = 15932
					},
					{
						-- Thaddius
						encounterId = 15928,
						npcIds = {15928, 15930, 15929 }
					},
					{
						-- Sapphiron
						encounterId = 15989,
						npcIds = { 15989, 16474 }
					},
					{
						-- Kel'Thuzad
						encounterId = 15990,
						npcIds = { 15990, 16441, 16129, 16428 }
					}
				}
			},
			{
				instanceId = "TheEyeOfEternity",
				encounters = {
					{
						-- Malygos
						encounterId = 28859,
						npcIds = { 28859, 30245, 30249, 30592, 30084 }
					}
				}
			},
			{
				instanceId = "TheObsidianSanctum",
				npcIds = { 30681, 30680, 30682, 30453 },
				encounters = {
					{
						-- Sartharion
						encounterId = 28860,
						npcIds = { 28860, 30451, 30452, 30449, 30641, 31214 }
					}
				}
			},
			{
				instanceId = "VaultOfArchavon",
				encounters = {
					{
						-- Archavon the Stone Watcher
						encounterId = 31125
					}
				}
			}
		}
	},
	
	-- Wrath of the Lich King Dungeons
	{
		instanceSetId = "WotlkDungeon",
		default = true,
		instances = {
			{
				instanceId = "HallsOfLightning",
				encounters = {
					{
						-- General Bjarngrim
						encounterId = 28586
					},
					{
						-- Volkhan
						encounterId = 28587
					},
					{
						-- Ionar
						encounterId = 28546
					},
					{
						-- Loken
						encounterId = 28923
					}
				}
			},
			{
				instanceId = "TheCullingOfStratholme",
				encounters = {
					{
						-- Meathook
						encounterId = 26529
					},
					{
						-- Salramm the Fleshcrafter
						encounterId = 26530
					},
					{
						-- Chrono-Lord Epoch
						encounterId = 26532
					},
					{
						-- Mal'Ganis
						encounterId = 26533
					},
					{
						-- Infinite Corruptor
						encounterId = 32273
					}
				}
			},
			{
				instanceId = "TheOculus",
				encounters = {
					{
						-- Drakos The Interrogator
						encounterId = 27654
					},
					{
						-- Varos Cloudstrider
						encounterId = 27447
					},
					{
						-- Mage-Lord Urom
						encounterId = 27655
					},
					{
						-- Ley-Guardian Eregos
						encounterId = 27656
					}
				}
			},
			{
				instanceId = "UtgardePinnacle",
				encounters = {
					{
						-- Svala Sorrowgrave
						encounterId = 26668
					},
					{
						-- Gortok Palehoof
						encounterId = 26687
					},
					{
						-- Skdadi the Ruthless
						encounterId = 26693
					},
					{
						-- King Ymiron
						encounterId = 26861
					}
				}
			},
			{
				instanceId = "HallsOfStone",
				encounters = {
					{
						-- Maiden of Grief
						encounterId = 27975
					},
					{
						-- Krystallus
						encounterId = 27977
					},
					{
						-- Tribunal of Ages
						encounterId = 27983,
						npcIds = { 27983, 27984, 27985 }
					},
					{
						-- Sjonnir The Ironshaper
						encounterId = 27978
					}
				}
			},
			{
				instanceId = "Gundrak",
				encounters = {
					{
						-- Slad'ran
						encounterId = 29304
					},
					{
						-- Drakkari Colossus
						encounterId = 29307,
						npcIds = { 29307, 29573 }
					},
					{
						-- Moorabi
						encounterId = 29305
					},
					{
						-- Gal'darah
						encounterId = 29306
					},
					{
						-- Eck the Ferocious
						encounterId = 29932
					}
				}
			},
			{
				instanceId = "TheVioletHold",
				npcIds = { 30918, 30666, 30661, 30961, 30664, 30668, 31079, 30667, 32191, 30837, 30660, 30892, 30695, 30893 },
				encounters = {
					{
						-- Erekem
						encounterId = 29315,
						npcIds = { 29315, 29395 }
					},
					{
						-- Moragg
						encounterId = 29316
					},
					{
						-- Ichoron
						encounterId = 29313,
						npcIds = { 29313, 29321 }
					},
					{
						-- Xevozz
						encounterId = 29266
					},
					{
						-- Lavanthor
						encounterId = 29312
					},
					{
						-- Zuramat The Obliterator
						encounterId = 29314
					},
					{
						-- Cayanigosa
						encounterId = 31134
					}
				}
			},
			{
				instanceId = "DrakTharonKeep",
				npcIds = { 26625, 26620, 26641, 26639, 27431, 27871, 26621, 26638, 26830, 26637,
						26636,  26635, 26623, 26626, 26624 },
				encounters = {
					{
						-- Trollgore
						encounterId = 26630
					},
					{
						-- Novos The Summonor
						encounterId = 26631,
						npcIds = { 26631, 26627, 27600 },
					},
					{
						-- King Dred
						encounterId = 27483,
						npcIds = { 27483, 26628 }
					},
					{
						-- The Prophet Tharon'ja
						encounterId = 26632
					}
				}
			},
			{
				instanceId = "AhnKahetTheOldKingdom",
				encounters = {
					{
						-- Elder Nadox
						encounterId = 29309
					},
					{
						-- Prince Taldaram
						encounterId = 29308
					},
					{
						-- Jedoga Shadowseeker
						encounterId = 29310
					},
					{
						-- Herald Volazj
						encounterId = 29311
					},
					{
						-- Amanitar
						encounterId = 30258
					}
				}
			},
			{
				instanceId = "AzjolNerub",
				encounters = {
					{
						-- Krik'thir the Gatewatcher
						encounterId = 28684
					},
					{
						-- Hadronox
						encounterId = 28921
					},
					{
						-- Anub'arak
						encounterId = 29120
					}
				}
			},
			{
				instanceId = "TheNexus",
				encounters = {
					{
						-- Grand Magus Telestra
						encounterId = 26731,
						npcIds = { 26731, 29928, 26929, 26930 }
					},
					{
						-- Anomalus
						encounterId = 26763
					},
					{
						-- Ormorok The Tree-Shaper
						encounterId = 26794
					},
					{
						-- Keristrsza
						encounterId = 27723
					},
					{
						-- Commander Stoutbeard
						encounterId = 26795
					},
					{
						-- Commander Kolurg
						encounterId = 26798
					}
				}
			},
			{
				instanceId = "UtgardeKeep",
				npcIds = { 24069, 24079, 24071, 23961, 24078, 24085, 23960, 28410, 23956, 24080, 24082, 24849, 29735, 32246, 24084 },
				encounters = {
					{
						-- Prince Keleseth
						encounterId = 23953,
						npcIds = { 23953, 23970 },
					},
					{
						-- Skarvald & Dalronn
						encounterId = 24200,
						npcIds = { 24200, 24201 }
					},
					{
						-- Ingvar the Punderer
						encounterId = 23954
					}
				}
			}
		}
	},
	
	-- The Burning Crusade Raid
	{
		instanceSetId = "TbcRaid",
		default = false,
		instances = {
			{
				instanceId = "SunwellPlateau",
				encounters = {
					{
						-- Kalecgos
						encounterId = 24850,
						npcIds = { 24850, 24892 }
					},
					{
						-- Brutallus
						encounterId = 24882
					},
					{
						-- Felmyst
						encounterId = 25038
					},
					{
						-- Eredar Twins
						encounterId = 25164,
						npcIds = { 25166, 25164 }
					},
					{
						-- M'uru
						encounterId = 25741,
						npcIds = { 25741, 25840 }
					},
					{
						-- Kil'jaeden
						encounterId = 25315
					}
				}
			},
			{
				instanceId = "BlackTemple",
				encounters = {
					{
						-- High Warlord Naj'entus
						encounterId = 22887
					},
					{
						-- Supremus
						encounterId = 22898
					},
					{
						-- Shade of Akama
						encounterId = 22841
					},
					{
						-- Teron Gorefiend
						encounterId = 22871
					},
					{
						-- Gurtogg Bloodboil
						encounterId = 22948
					},
					{
						-- Reqliquary of Souls
						encounterId = 23418,
						npcIds = { 23418, 23419, 23420 }
					},
					{
						-- Mother Shahraz
						encounterId = 22947
					},
					{
						-- The Illidari Council
						encounterId = 22949,
						npcIds = { 22949, 22950, 22951, 22952 }
					},
					{
						-- Illidan Stormrage
						encounterId = 22917
					}
				}
			},
			{
				instanceId = "HyjalSummit",
				encounters = {
					{
						-- Rage Winterchill
						encounterId = 17767
					},
					{
						-- Anetheron
						encounterId = 17808
					},
					{
						-- Kaz'rogal
						encounterId = 17888
					},
					{
						-- Azgalor
						encounterId = 17842
					},
					{
						-- Archimonde
						encounterId = 17968
					}
				}
			},
			{
				instanceId = "ZulAman",
				encounters = {
					{
						-- Akil'zon
						encounterId = 23574
					},
					{
						-- Nalorakk
						encounterId = 23576
					},
					{
						-- Jan'alai
						encounterId = 23578
					},
					{
						-- Halazzi
						encounterId = 23577
					},
					{
						-- Hex Lord Malacrass
						encounterId = 24239
					},
					{
						-- Zul'jin
						encounterId = 23863
					}
				}
			},
			{
				instanceId = "SerpentshrineCavern",
				encounters = {
					{
						-- Hydross the Unstable
						encounterId = 21216
					},
					{
						-- The Lurker Below
						encounterId = 21217
					},
					{
						-- Leotheras the Blind
						encounterId = 21215
					},
					{
						-- Fathom-Lord Karathress
						encounterId = 21214
					},
					{
						-- Morogrim Tidewalker
						encounterId = 21213
					},
					{
						-- Lady Vashj
						encounterId = 21212
					}
				}
			},
			{
				instanceId = "TheEye",
				encounters = {
					{
						-- Void Reaver
						encounterId = 19516
					},
					{
						-- A'lar
						encounterId = 19514
					},
					{
						-- High Astromancer Solarian
						encounterId = 18805
					},
					{
						-- Kael'thas Sunstrider
						encounterId = 19622
					}
				}
			},
			{
				instanceId = "MagtheridonsLair",
				encounters = {
					{
						-- Magtheridon
						encounterId = 17257
					}
				}
			},
			{
				instanceId = "GruulsLair",
				encounters = {
					{
						-- High King Maulgar
						encounterId = 18831,
						npcIds = { 18831, 18836, 18835, 18832, 18834 }
					},
					{
						-- Gruul the Dragonkiller
						encounterId = 19044
					}
				}
			},
			{
				instanceId = "Karazhan",
				encounters = {
					{
						-- Servant Quarters
						encounterId = 16179,
						npcIds = { 16179, 16181, 16180 },
					},
					{
						-- Atumen the Huntsman
						encounterId = 15550,
						npcIds = { 15550, 16151 }
					},
					{
						-- Moroes
						encounterId = 15687
					},
					{
						-- Maiden of Virtue
						encounterId = 16457
					},
					{
						-- Opera Event
						encounterId = 17521,
						npcIds = { 17521, 17533, 15534, 18168, 17535, 17546, 17543, 17547, 17548 }
					},
					{
						-- Nightbane
						encounterId = 17225
					},
					{
						-- The Curator
						encounterId = 15691
					},
					{
						-- Terestian Illhoof
						encounterId = 15688
					},
					{
						-- Shade of Aran
						encounterId = 16524
					},
					{
						-- Netherspite
						encounterId = 15689
					},
					{
						-- Chess Event
						encounterId = 16816
					},
					{
						-- Prince Malchezaar
						encounterId = 15690
					}
				}
			}
		}
	},
	
	-- The Burning Crusade Dungeon
	{
		instanceSetId = "TbcDungeon",
		default = false,
		instances = {
		}
	},
	
	-- Classic Raid
	{
		instanceSetId = "ClassicRaid",
		default = false,
		instances = {
			{
				instanceId = "TempleOfAhnQiraj",
				encounters = {
					{
						-- The Prophet Skeram
						encounterId = 15263
					},
					{
						-- Battleguard Sartura
						encounterId = 15516
					},
					{
						-- Fankriss the Unyielding
						encounterId = 15510
					},
					{
						-- Princess Huhuran
						encounterId = 15509
					},
					{
						-- Twin Emperors
						encounterId = 15275,
						npcIds = { 15276, 15275 }
					},
					{
						-- C'Thun
						encounterId = 15727
					},
					{
						-- Bug Trio
						encounterId = 15511,
						npcIds = { 15543, 15544, 15511 }
					},
					{
						-- Viscidus
						encounterId = 15299
					},
					{
						-- Ouro
						encounterId = 15517
					}
				}
			},
			{
				instanceId = "BlackwingLair",
				encounters = {
					{
						-- Razorgore the Untamed
						encounterId = 12435
					},
					{
						-- Vaelastrasz the Corrupt
						encounterId = 13020
					},
					{
						-- Broodlord Lashlayer
						encounterId = 12017
					},
					{
						-- Firemaw
						encounterId = 11983
					},
					{
						-- Ebonroc
						encounterId = 14601
					},
					{
						-- Flamegor
						encounterId = 11981
					},
					{
						-- Chromaggus
						encounterId = 14020
					},
					{
						-- Nefarian
						encounterId = 11583
					}
				}
			},
			{
				instanceId = "MoltenCore",
				npcIds = { 11673, 11671, 11668, 11666, 11667, 11669, 12076, 12100, 12265, 12101, 11659, 11658 },
				encounters = {
					{
						-- Lucifron
						encounterId = 12118,
						npcIds = { 12118, 12119 },
					},
					{
						-- Magmadar
						encounterId = 11982
					},
					{
						-- Gehenas
						encounterId = 12259,
						npcIds = { 12259, 11661 },
					},
					{
						-- Garr
						encounterId = 12057,
						npcIds = { 12057, 12099 },
					},
					{
						--Shazzrah
						encounterId = 12264,
					},
					{
						-- Baron Geddon
						encounterId = 12056
					},
					{
						-- Golemagg the Incinerator
						encounterId = 11988,
						npcIds = { 11988, 11672 },
					},
					{
						-- Sulfuron Harbinger
						encounterId = 12098,
						npcIds = { 12098, 11662 },
					},
					{
						-- Majordomo Executus
						encounterId = 12018,
						npcIds = { 12018, 11663, 11664 },
					},
					{
						-- Ragnaros
						encounterId = 11502
					}
				}
			},
			{
				instanceId = "OnyxiasLair",
				encounters = {
					{
						-- Onyxia
						encounterId = 10184
					}
				}
			},
			{
				instanceId = "RuinsOfAhnQiraj",
				encounters = {
					{
						-- Kurinnaxx
						encounterId = 15348
					},
					{
						-- General Rajaxx
						encounterId = 15341
					},
					{
						-- Moam
						encounterId = 15340
					},
					{
						-- Buru the Gorger
						encounterId = 15370
					},
					{
						-- Ayamiss the Hunter
						encounterId = 15369
					},
					{
						-- Ossirian the Unscarred
						encounterId = 15339
					}
				}
			},
			{
				instanceId = "ZulGurub",
				encounters = {
					{
						-- High Priest Venoxis
						encounterId = 14507
					},
					{
						-- High Priestess Jeklik
						encounterId = 14517
					},
					{
						-- High Priestess Mar'li
						encounterId = 14510
					},
					{
						-- High Priest Thekal
						encounterId = 14509
					},
					{
						-- High Priestess Arlokk
						encounterId = 14515
					},
					{
						-- Hakkar the Soulflayer
						encounterId = 14834
					},
					{
						-- Bloodlord Mandokir
						encounterId = 11382,
						npcIds = { 11382, 14988 }
					},
					{
						-- Edge of Madness
						encounterId = 15082,
						npcIds = { 15082, 15083, 15084, 15085 }
					},
					{
						-- Gahz'ranka
						encounterId = 15114
					},
					{
						-- Jin'do the Hexxer
						encounterId = 11380
					}
				}
			}
		}
	},
	
	-- Classic Dungeon
	{
		instanceSetId = "ClassicDungeon",
		default = false,
		instances = {
		}
	}
}

-- Fixup
for _, instanceSet in ipairs(BOSS_NOTES_ENCOUNTERS) do
	instanceSet.name = L[instanceSet.instanceSetId]
	for _, instance in ipairs(instanceSet.instances) do
		instance.name = L["instance:" .. instance.instanceId]
		if not instance.npcIds then
			instance.npcIds = { }
		end
		for _, encounter in ipairs(instance.encounters) do
			encounter.name = L["encounter:" .. encounter.encounterId]
			if not encounter.npcIds then
				encounter.npcIds = { encounter.encounterId }
			end
		end
	end
end
